@@ -78,6 +78,7 @@
 #define _INTEL_XVMC_SERVER_
 #include "intel_xvmc.h"
 #endif
+#include "intel_glamor.h"
 
 #define OFF_DELAY	250	/* milliseconds */
 
@@ -331,13 +332,13 @@ void I830InitVideo(ScreenPtr screen)
 	ScrnInfoPtr scrn = xf86ScreenToScrn(screen);
 	intel_screen_private *intel = intel_get_screen_private(scrn);
 	XF86VideoAdaptorPtr *adaptors = NULL, *newAdaptors = NULL;
-	XF86VideoAdaptorPtr overlayAdaptor = NULL, texturedAdaptor = NULL;
+	XF86VideoAdaptorPtr overlayAdaptor = NULL, texturedAdaptor = NULL, glamorAdaptor = NULL;
 	int num_adaptors = xf86XVListGenericAdaptors(scrn, &adaptors);
 	/* Give our adaptor list enough space for the overlay and/or texture video
 	 * adaptors.
 	 */
 	newAdaptors = realloc(adaptors,
-			      (num_adaptors + 2) * sizeof(XF86VideoAdaptorPtr));
+			      (num_adaptors + 3) * sizeof(XF86VideoAdaptorPtr));
 	if (newAdaptors == NULL) {
 		free(adaptors);
 		return;
@@ -378,12 +379,20 @@ void I830InitVideo(ScreenPtr screen)
 		}
 	}
 
+	glamorAdaptor = intel_glamor_xv_init(screen, 16);
+	if (glamorAdaptor != NULL)
+		xf86DrvMsg(scrn->scrnIndex, X_INFO,
+			   "Set up textured video using glamor\n");
+
 	if (overlayAdaptor && intel->XvPreferOverlay)
 		adaptors[num_adaptors++] = overlayAdaptor;
 
 	if (texturedAdaptor)
 		adaptors[num_adaptors++] = texturedAdaptor;
 
+	if (glamorAdaptor)
+		adaptors[num_adaptors++] = glamorAdaptor;
+
 	if (overlayAdaptor && !intel->XvPreferOverlay)
 		adaptors[num_adaptors++] = overlayAdaptor;
 
